==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1StorageClassFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface V1StorageClassFluent<A extends V1StorageClassFluent<A>> extends Fluent<A>{


    public Boolean isAllowVolumeExpansion();
    public A withAllowVolumeExpansion(Boolean allowVolumeExpansion);
    public Boolean hasAllowVolumeExpansion();
    public A withNewAllowVolumeExpansion(boolean arg1);
    public A withNewAllowVolumeExpansion(String arg1);
    public A addToAllowedTopologies(int index,V1TopologySelectorTerm item);
    public A setToAllowedTopologies(int index,V1TopologySelectorTerm item);
    public A addToAllowedTopologies(V1TopologySelectorTerm... items);
    public A addAllToAllowedTopologies(Collection<V1TopologySelectorTerm> items);
    public A removeFromAllowedTopologies(V1TopologySelectorTerm... items);
    public A removeAllFromAllowedTopologies(Collection<V1TopologySelectorTerm> items);
    
/**
 * This method has been deprecated, please use method buildAllowedTopologies instead.
 * @return The buildable object.
 */
@Deprecated public List<V1TopologySelectorTerm> getAllowedTopologies();
    public List<V1TopologySelectorTerm> buildAllowedTopologies();
    public V1TopologySelectorTerm buildAllowedTopology(int index);
    public V1TopologySelectorTerm buildFirstAllowedTopology();
    public V1TopologySelectorTerm buildLastAllowedTopology();
    public V1TopologySelectorTerm buildMatchingAllowedTopology(io.kubernetes.client.fluent.Predicate<V1TopologySelectorTermBuilder> predicate);
    public A withAllowedTopologies(List<V1TopologySelectorTerm> allowedTopologies);
    public A withAllowedTopologies(V1TopologySelectorTerm... allowedTopologies);
    public Boolean hasAllowedTopologies();
    public V1StorageClassFluent.AllowedTopologiesNested<A> addNewAllowedTopology();
    public V1StorageClassFluent.AllowedTopologiesNested<A> addNewAllowedTopologyLike(V1TopologySelectorTerm item);
    public V1StorageClassFluent.AllowedTopologiesNested<A> setNewAllowedTopologyLike(int index,V1TopologySelectorTerm item);
    public V1StorageClassFluent.AllowedTopologiesNested<A> editAllowedTopology(int index);
    public V1StorageClassFluent.AllowedTopologiesNested<A> editFirstAllowedTopology();
    public V1StorageClassFluent.AllowedTopologiesNested<A> editLastAllowedTopology();
    public V1StorageClassFluent.AllowedTopologiesNested<A> editMatchingAllowedTopology(io.kubernetes.client.fluent.Predicate<V1TopologySelectorTermBuilder> predicate);
    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1StorageClassFluent.MetadataNested<A> withNewMetadata();
    public V1StorageClassFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1StorageClassFluent.MetadataNested<A> editMetadata();
    public V1StorageClassFluent.MetadataNested<A> editOrNewMetadata();
    public V1StorageClassFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    public A addToMountOptions(int index,String item);
    public A setToMountOptions(int index,String item);
    public A addToMountOptions(String... items);
    public A addAllToMountOptions(Collection<String> items);
    public A removeFromMountOptions(String... items);
    public A removeAllFromMountOptions(Collection<String> items);
    public List<String> getMountOptions();
    public String getMountOption(int index);
    public String getFirstMountOption();
    public String getLastMountOption();
    public String getMatchingMountOption(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withMountOptions(List<String> mountOptions);
    public A withMountOptions(String... mountOptions);
    public Boolean hasMountOptions();
    public A addToParameters(String key,String value);
    public A addToParameters(Map<String,String> map);
    public A removeFromParameters(String key);
    public A removeFromParameters(Map<String,String> map);
    public Map<String,String> getParameters();
    public A withParameters(Map<String,String> parameters);
    public Boolean hasParameters();
    public String getProvisioner();
    public A withProvisioner(String provisioner);
    public Boolean hasProvisioner();
    public String getReclaimPolicy();
    public A withReclaimPolicy(String reclaimPolicy);
    public Boolean hasReclaimPolicy();
    public String getVolumeBindingMode();
    public A withVolumeBindingMode(String volumeBindingMode);
    public Boolean hasVolumeBindingMode();

    public interface AllowedTopologiesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1TopologySelectorTermFluent<V1StorageClassFluent.AllowedTopologiesNested<N>>{

        
    public N and();    public N endAllowedTopology();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1StorageClassFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1StorageClassFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface V1StorageClassFluent<A extends V1StorageClassFluent<A>> extends Fluent<A>{


    public Boolean isAllowVolumeExpansion();
    public A withAllowVolumeExpansion(Boolean allowVolumeExpansion);
    public Boolean hasAllowVolumeExpansion();
    public A withNewAllowVolumeExpansion(String arg1);
    public A withNewAllowVolumeExpansion(boolean arg1);
    public A addToAllowedTopologies(int index,V1TopologySelectorTerm item);
    public A setToAllowedTopologies(int index,V1TopologySelectorTerm item);
    public A addToAllowedTopologies(V1TopologySelectorTerm... items);
    public A addAllToAllowedTopologies(Collection<V1TopologySelectorTerm> items);
    public A removeFromAllowedTopologies(V1TopologySelectorTerm... items);
    public A removeAllFromAllowedTopologies(Collection<V1TopologySelectorTerm> items);
    
/**
 * This method has been deprecated, please use method buildAllowedTopologies instead.
 * @return The buildable object.
 */
@Deprecated public List<V1TopologySelectorTerm> getAllowedTopologies();
    public List<V1TopologySelectorTerm> buildAllowedTopologies();
    public V1TopologySelectorTerm buildAllowedTopology(int index);
    public V1TopologySelectorTerm buildFirstAllowedTopology();
    public V1TopologySelectorTerm buildLastAllowedTopology();
    public V1TopologySelectorTerm buildMatchingAllowedTopology(io.kubernetes.client.fluent.Predicate<V1TopologySelectorTermBuilder> predicate);
    public Boolean hasMatchingAllowedTopology(io.kubernetes.client.fluent.Predicate<V1TopologySelectorTermBuilder> predicate);
    public A withAllowedTopologies(List<V1TopologySelectorTerm> allowedTopologies);
    public A withAllowedTopologies(V1TopologySelectorTerm... allowedTopologies);
    public Boolean hasAllowedTopologies();
    public V1StorageClassFluent.AllowedTopologiesNested<A> addNewAllowedTopology();
    public V1StorageClassFluent.AllowedTopologiesNested<A> addNewAllowedTopologyLike(V1TopologySelectorTerm item);
    public V1StorageClassFluent.AllowedTopologiesNested<A> setNewAllowedTopologyLike(int index,V1TopologySelectorTerm item);
    public V1StorageClassFluent.AllowedTopologiesNested<A> editAllowedTopology(int index);
    public V1StorageClassFluent.AllowedTopologiesNested<A> editFirstAllowedTopology();
    public V1StorageClassFluent.AllowedTopologiesNested<A> editLastAllowedTopology();
    public V1StorageClassFluent.AllowedTopologiesNested<A> editMatchingAllowedTopology(io.kubernetes.client.fluent.Predicate<V1TopologySelectorTermBuilder> predicate);
    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1StorageClassFluent.MetadataNested<A> withNewMetadata();
    public V1StorageClassFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1StorageClassFluent.MetadataNested<A> editMetadata();
    public V1StorageClassFluent.MetadataNested<A> editOrNewMetadata();
    public V1StorageClassFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    public A addToMountOptions(int index,String item);
    public A setToMountOptions(int index,String item);
    public A addToMountOptions(String... items);
    public A addAllToMountOptions(Collection<String> items);
    public A removeFromMountOptions(String... items);
    public A removeAllFromMountOptions(Collection<String> items);
    public List<String> getMountOptions();
    public String getMountOption(int index);
    public String getFirstMountOption();
    public String getLastMountOption();
    public String getMatchingMountOption(io.kubernetes.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingMountOption(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withMountOptions(List<String> mountOptions);
    public A withMountOptions(String... mountOptions);
    public Boolean hasMountOptions();
    public A addNewMountOption(String arg1);
    public A addNewMountOption(StringBuilder arg1);
    public A addNewMountOption(StringBuffer arg1);
    public A addToParameters(String key,String value);
    public A addToParameters(Map<String,String> map);
    public A removeFromParameters(String key);
    public A removeFromParameters(Map<String,String> map);
    public Map<String,String> getParameters();
    public A withParameters(Map<String,String> parameters);
    public Boolean hasParameters();
    public String getProvisioner();
    public A withProvisioner(String provisioner);
    public Boolean hasProvisioner();
    public A withNewProvisioner(String arg1);
    public A withNewProvisioner(StringBuilder arg1);
    public A withNewProvisioner(StringBuffer arg1);
    public String getReclaimPolicy();
    public A withReclaimPolicy(String reclaimPolicy);
    public Boolean hasReclaimPolicy();
    public A withNewReclaimPolicy(String arg1);
    public A withNewReclaimPolicy(StringBuilder arg1);
    public A withNewReclaimPolicy(StringBuffer arg1);
    public String getVolumeBindingMode();
    public A withVolumeBindingMode(String volumeBindingMode);
    public Boolean hasVolumeBindingMode();
    public A withNewVolumeBindingMode(String arg1);
    public A withNewVolumeBindingMode(StringBuilder arg1);
    public A withNewVolumeBindingMode(StringBuffer arg1);

    public interface AllowedTopologiesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1TopologySelectorTermFluent<V1StorageClassFluent.AllowedTopologiesNested<N>>{

        
    public N and();    public N endAllowedTopology();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1StorageClassFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
